Advertisement class abstract interface

The advertisement of the peripheral.

Implementers

Constructors

Advertisement({String? name, List<UUID> serviceUUIDs = const [], Map<UUID, Uint8List> serviceData = const {}, List<ManufacturerSpecificData> manufacturerSpecificData = const []})
Constructs an Advertisement.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
manufacturerSpecificData List<ManufacturerSpecificData>
The manufacturer specific data of the peripheral.
no setter
name String?
The name of the peripheral.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceData Map<UUID, Uint8List>
The GATT service data of the peripheral.
no setter
serviceUUIDs List<UUID>
The GATT service uuids of the peripheral.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited