The abstract base class that manages central and peripheral objects.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → BluetoothLowEnergyState
-
Gets the manager's state.
no setter
-
stateChanged
→ Stream<
BluetoothLowEnergyStateChangedEventArgs> -
Tells the manager's state updated.
no setter
Methods
- Requests permissions to be granted to this application. These permissions must be requested in your manifest, they should not be granted to your app, and they should have protection level dangerous, regardless whether they are declared by the platform or a third-party app.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
showAppSettings(
) → Future< void> - Show screen of details about a particular application.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited