CentralManagerChannel class abstract base

Platform-specific implementations should implement this class to support CentralManagerChannel.

Inheritance
  • Object
  • PlatformInterface
  • CentralManagerChannel

Constructors

CentralManagerChannel()
Constructs a CentralManagerChannel.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() CentralManager
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CentralManagerChannel
The default instance of CentralManagerChannel to use.
getter/setter pair