A characteristic of a remote peripheral’s service.
- Implemented types
- Implementers
Constructors
-
GATTCharacteristic.immutable({required UUID uuid, required Uint8List value, required List<
GATTDescriptor> descriptors}) -
Creates a immutable characteristic with a specified value.
factory
-
GATTCharacteristic.mutable({required UUID uuid, required List<
GATTCharacteristicProperty> properties, required List<GATTCharacteristicPermission> permissions, required List<GATTDescriptor> descriptors}) -
Creates a mutable characteristic with specified permissions, properties.
factory
Properties
-
descriptors
→ List<
GATTDescriptor> -
A list of the descriptors discovered in this characteristic.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ List<
GATTCharacteristicProperty> -
The properties of the characteristic.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → UUID
-
The Bluetooth-specific UUID of the attribute.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited