A collection of data and associated behaviors that accomplish a function or feature of a device.
- Implemented types
- Implementers
Constructors
-
GATTService({required UUID uuid, required bool isPrimary, required List<
GATTService> includedServices, required List<GATTCharacteristic> characteristics}) -
Creates a newly initialized mutable service specified by UUID and service
type.
factory
Properties
-
characteristics
→ List<
GATTCharacteristic> -
A list of characteristics discovered in this service.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includedServices
→ List<
GATTService> -
A list of included services discovered in this service.
no setter
- isPrimary → bool
-
A Boolean value that indicates whether the type of service is primary or
secondary.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → UUID
-
The Bluetooth-specific UUID of the attribute.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited