ImmutableGATTDescriptorImpl class final
An object that provides additional information about a local peripheral’s characteristic.
- Inheritance
-
- Object
- GATTAttributeImpl
- MutableGATTDescriptorImpl
- ImmutableGATTDescriptorImpl
Constructors
- ImmutableGATTDescriptorImpl({required UUID uuid, required Uint8List value})
- Creates an immutable descriptor with a specified value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permissions
→ List<
GATTCharacteristicPermission> -
The permissions of the descriptor value.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → UUID
-
The Bluetooth-specific UUID of the attribute.
finalinherited
- value → Uint8List
-
The value of the descriptor.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited