ManufacturerSpecificData class abstract interface

The manufacturer specific data of the peripheral

Implementers

Constructors

ManufacturerSpecificData({required int id, required Uint8List data})
Constructs an ManufacturerSpecificData.
factory

Properties

data Uint8List
The manufacturer data.
no setter
hashCode int
The hash code for this object.
no setterinherited
id int
The manufacturer id.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited