MutableGATTCharacteristicImpl class final

A mutable characteristic of a local peripheral’s service.

Inheritance
Implemented types
Implementers

Constructors

MutableGATTCharacteristicImpl({required UUID uuid, required List<GATTCharacteristicProperty> properties, required List<GATTCharacteristicPermission> permissions, required List<MutableGATTDescriptorImpl> descriptors})
Creates a mutable characteristic with specified permissions, properties.

Properties

descriptors List<MutableGATTDescriptorImpl>
A list of the descriptors discovered in this characteristic.
final
hashCode int
The hash code for this object.
no setterinherited
permissions List<GATTCharacteristicPermission>
The permissions of the characteristic value.
final
properties List<GATTCharacteristicProperty>
The properties of the characteristic.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid UUID
The Bluetooth-specific UUID of the attribute.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited