MutableGATTDescriptorImpl class final
An object that provides additional information about a local peripheral’s characteristic.
- Inheritance
-
- Object
- GATTAttributeImpl
- MutableGATTDescriptorImpl
- Implemented types
- Implementers
Constructors
-
MutableGATTDescriptorImpl({required UUID uuid, required List<
GATTCharacteristicPermission> permissions}) - Creates a mutable descriptor with a specified value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permissions
→ List<
GATTCharacteristicPermission> -
The permissions of the descriptor value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → UUID
-
The Bluetooth-specific UUID of the attribute.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited