MutableGATTServiceImpl class final

Inheritance
Implemented types

Constructors

MutableGATTServiceImpl({required UUID uuid, required bool isPrimary, required List<MutableGATTServiceImpl> includedServices, required List<MutableGATTCharacteristicImpl> characteristics})

Properties

characteristics List<MutableGATTCharacteristicImpl>
A list of characteristics discovered in this service.
final
hashCode int
The hash code for this object.
no setterinherited
includedServices List<MutableGATTServiceImpl>
A list of included services discovered in this service.
final
isPrimary bool
A Boolean value that indicates whether the type of service is primary or secondary.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid UUID
The Bluetooth-specific UUID of the attribute.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited