PeripheralManagerChannel class abstract base

Platform-specific implementations should implement this class to support PeripheralManagerChannel.

Inheritance
  • Object
  • PlatformInterface
  • PeripheralManagerChannel

Constructors

PeripheralManagerChannel()
Constructs a PeripheralManagerChannel.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create() PeripheralManager
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance PeripheralManagerChannel
The default instance of PeripheralManagerChannel to use.
getter/setter pair