ImmutableGATTCharacteristicImpl class final
An immutable characteristic of a local peripheral’s service.
- Inheritance
-
- Object
- GATTAttributeImpl
- MutableGATTCharacteristicImpl
- ImmutableGATTCharacteristicImpl
Constructors
-
ImmutableGATTCharacteristicImpl({required UUID uuid, required Uint8List value, required List<
MutableGATTDescriptorImpl> descriptors}) - Creates an immutable characteristic with a specified value.
Properties
-
descriptors
→ List<
MutableGATTDescriptorImpl> -
A list of the descriptors discovered in this characteristic.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
permissions
→ List<
GATTCharacteristicPermission> -
The permissions of the characteristic value.
finalinherited
-
properties
→ List<
GATTCharacteristicProperty> -
The properties of the characteristic.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → UUID
-
The Bluetooth-specific UUID of the attribute.
finalinherited
- value → Uint8List
-
The value of the characteristic.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited